@@ -130,6 +130,11 @@ class MurckoRingFragmenter(Fragmenter):
         super(MurckoRingFragmenter, self).__init__()
         self.use_scheme_4 = use_scheme_4
 
+    def extractRings1(self, str6):
+        return [int(str6[0:2])-1, int(str6[2:4]) -1, int(str6[4:6]) -1]
+        
+
+
     def fragment(self, scaffold):
         """Fragment a scaffold into its next set of Murcko fragments.
 
@@ -207,25 +212,51 @@ class MurckoRingFragmenter(Fragmenter):
                 molPBlok = MolToMolBlock(parent.mol, kekulize=False);
                 #print(molPBlok)
 
-                arom_atoms = []
+                #arom_atoms = []
                 atomCount = len(parent.mol.GetAtoms())
                 bondCount = len(parent.mol.GetBonds())
                 #print(atomCount)
                 idxV2000 = molPBlok.index("V2000\n")
                 idxV2000ToEnd = molPBlok.index("\n", idxV2000) +1
+
+                all_rings = []
+                #for idx_atom in range(atomCount):
+                all_rings.append([])
+                                
                 for idx_atom in range(atomCount):
-                    idxV2000ToEnd = idxV2000ToEnd + 56
-                    if molPBlok[idxV2000ToEnd] == "1":
-                        arom_atoms.append(idx_atom +1)
+                    
+                    idxV2000ToEnd = idxV2000ToEnd + 54 #56
+                    #if molPBlok[idxV2000ToEnd] == "1":
+                        #arom_atoms.append(idx_atom +1)
+                    sixLetters = molPBlok[idxV2000ToEnd: idxV2000ToEnd+6]
+                    sixLetters = sixLetters.replace(' ', '0');
+                    #print('sixLetters')
+                    #print(sixLetters)
+
+                    if sixLetters != '000000':
+                        atom_rings = self.extractRings1(sixLetters)
+                        for idx_ring in atom_rings:
+                            if idx_ring != -1:
+                                if len(all_rings)-1 < idx_ring:
+                                    for idx_at in range(0, idx_ring - len(all_rings)+1):
+                                      all_rings.append([])
+                                                                                                
+                                all_rings[idx_ring].append(idx_atom)
+                                
                     idxV2000ToEnd = molPBlok.index("\n", idxV2000ToEnd) +1
-                #print(arom_atoms)
-               
+                               
                 for idx_bond in range(bondCount):
                     atom_1 = int(molPBlok[idxV2000ToEnd: idxV2000ToEnd+3])
                     atom_2 = int(molPBlok[idxV2000ToEnd+4: idxV2000ToEnd+6])
                     #print(atom_1)
                     #print(atom_2)
-                    if atom_1 in arom_atoms and atom_2 in arom_atoms:
+                    b = False
+                    for idx_ring in range(0, len(all_rings)):
+                        if atom_1 -1 in all_rings[idx_ring] and atom_2 -1 in all_rings[idx_ring]:
+                            b = True;
+                            break
+
+                    if b:#atom_1 in arom_atoms and atom_2 in arom_atoms:
                         molPBlok = molPBlok[:idxV2000ToEnd + 8] + "4" + molPBlok[idxV2000ToEnd + 9:]
                     idxV2000ToEnd = molPBlok.index("\n", idxV2000ToEnd) +1
 
