@@ -14,7 +14,7 @@ from loguru import logger
 from tqdm.auto import tqdm
 
 from rdkit import __version__ as rdversion
-from rdkit.Chem import rdMolHash, MolToSmiles, rdmolops, MolToMolBlock, MolFromMolBlock, MolFromSmarts, SetAromaticity, AROMATICITY_SIMPLE
+from rdkit.Chem import rdMolHash, MolToSmiles, rdmolops, MolToMolBlock, MolFromMolBlock, MolFromSmarts, GetSymmSSSR, SetAromaticity, AROMATICITY_SIMPLE
 from rdkit.Chem.rdMolDescriptors import CalcNumRings
 
 from scaffoldgraph.io import *
@@ -145,6 +145,26 @@ class ScaffoldGraph(nx.DiGraph, ABC):
         self.graph.setdefault('num_filtered', 0)  # track number of filtered mols.
         self.fragmenter = fragmenter
 
+    def toAromRingIndexStr(self, idxAtom, rings):
+        #arom_rings = []
+        strOut = ''
+        for ring_idx in range(len(rings)):
+            if idxAtom in rings[ring_idx]:
+                if ring_idx+1 > 9:
+                    strOut = strOut + str(ring_idx+1)
+                else: 
+                    strOut = strOut + '0' + str(ring_idx+1)
+
+        missing0Count = 6 - len(strOut);
+        if missing0Count < 0:
+            print('GLOBAL ERROR - TOUT EST FOUTU! - missing0Count < 0')
+
+        if missing0Count > 0:
+          strOut = strOut + '0'*missing0Count;
+
+        return strOut
+
+
     @suppress_rdlogger()
     def _construct(self, molecules, init_args, ring_cutoff=10, progress=False):
         """Private method for graph construction, called by constructors.
@@ -188,10 +208,25 @@ class ScaffoldGraph(nx.DiGraph, ABC):
                 continue
             
             blkOnMol = MolToMolBlock(molecule, kekulize=True)
-            molQTest = MolFromSmarts("[#6,#7,#8;a]")
+            molQTest = MolFromSmarts("[#6,#7,#8;#16,a]")
             arom_atom_indices_ = molecule.GetSubstructMatches(molQTest)#.map((s) => s[0]);
             arom_atom_indices = sorted(list(map(lambda x: x[0], arom_atom_indices_)))
             
+            
+            #rings = [set(x) for x in GetSymmSSSR(molecule)]
+            rings_aroma = [];
+            rings = [list(x) for x in GetSymmSSSR(molecule)]
+            
+            #print('before ring cycle')
+            for ring in rings:
+                if len(list(set(ring) - set(arom_atom_indices))) == 0:
+                    rings_aroma.append(ring);
+
+            #print('after ring cycle')
+            #print('SSSR')
+            #print(rings_aroma)
+
+
             #print('Before setting 11111')
             #print(editMolBlk)
             idxV2000 = blkOnMol.index("V2000\n")
@@ -201,13 +236,21 @@ class ScaffoldGraph(nx.DiGraph, ABC):
                 while count < idx_sorted: 
                     count = count + 1
                     idxV2000ToEnd = blkOnMol.index("\n", idxV2000ToEnd) +1
-                                
-                #editArmMolBlk = replace_str_index(editArmMolBlk, idxV2000ToEnd + 56, "1")
-                blkOnMol = blkOnMol[:idxV2000ToEnd + 56] + "1" + blkOnMol[idxV2000ToEnd + 57:]
+                
+                #print('before strOut')
+                strOut = self.toAromRingIndexStr(idx_sorted, rings_aroma)
+                #print('after strOut')
 
+                #editArmMolBlk = replace_str_index(editArmMolBlk, idxV2000ToEnd + 56, "1")
+                #blkOnMol = blkOnMol[:idxV2000ToEnd + 56] + "1" + blkOnMol[idxV2000ToEnd + 57:]
+                blkOnMol = blkOnMol[:idxV2000ToEnd + 54] + strOut + blkOnMol[idxV2000ToEnd + 60:]
+
+                #print('blkOnMol')
+                #print(blkOnMol)
 
             molecule = MolFromMolBlock(blkOnMol)
-            
+            #print('Molecule')
+            #print(molecule)
 
             init_molecule_name(molecule)
             #print('nofrings', CalcNumRings(molecule))
